from blue_geo import REPO_NAME

README = {
    "objects": {
        "test_blue_geo_watch_v4-diff-chilcotin-river-landslide-test": [
            f"[![bashtest](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml)"
        ],
        "test_blue_geo_watch_v4-modality-chilcotin-river-landslide-test": [
            f"[![bashtest](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml)"
        ],
        "geo-watch-2024-08-31-chilcotin-c": [
            "L1C and L2A mixed",
            "`2024-07-30/2024-08-09`",
        ],
        "geo-watch-2024-09-01-chilcotin-a": [],
        "geo-watch-2024-09-01-chilcotin-c": [
            "[on reddit](https://www.reddit.com/r/bash/comments/1f9cvyx/a_bash_python_tool_to_watch_a_target_in_satellite/).",
        ],
        "geo-watch-Chilcotin-2024-11-03": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
