README = {
    "objects": {
        "Sheerness-20x-2024-12-09-S8xKmn": [
            "half-blank frames, will rerun with content-ratio > 0.6.",
        ],
        "Sheerness-20x-2024-12-14-EDkXl0": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
