README = {
    "objects": {
        "geo-watch-DrugSuperLab-2024-11-19-13954": [
            "known issues: successive frames may have different projections."
        ],
        "DrugSuperLab-2024-12-08-pGErp2": [],
        "DrugSuperLab-2024-12-09-ZnmC5L": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
