README = {
    "objects": {
        "bellingcat-2024-09-27-nagorno-karabakh-2024-10-01-c-b": [],
        "bellingcat-2024-09-27-nagorno-karabakh-b": [],
        "bellingcat-2024-09-27-nagorno-karabakh-6X-a": [],
        "geo-watch-bellingcat-2024-09-27-nagorno-karabakh-6X-2024-10-05-b": [],
        "geo-watch-bellingcat-2024-09-27-nagorno-karabakh-6X-2024-10-06-a": [],
        "bellingcat-2024-09-27-nagorno-karabakh-6X-2024-12-14-EUUpS1": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
