def QgsRasterLayer(filename: str, layer_name: str):
    return None


class QgsProjectClass:
    def instance():
        return None


QgsProject = QgsProjectClass()


def QgsMapLayerStyle():
    return None


def QgsVectorLayer(filename: str, layer_name: str, driver: str):
    return None


class ifaceClass:
    def activeLayer():
        return None


iface = ifaceClass()


class QgsSettings:
    pass


class qgis_class:
    pass


qgis = qgis_class()
