from blue_geo import REPO_NAME

README = {
    "objects": {
        "test_blue_geo_watch_v4-diff-Leonardo-test": [
            f"[![bashtest](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml)"
        ],
        "test_blue_geo_watch_v4-modality-Leonardo-test": [
            f"[![bashtest](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/{REPO_NAME}/actions/workflows/bashtest.yml)"
        ],
        "geo-watch-2024-09-30-Leonardo-g": [],
        "geo-watch-Leonardo-2024-10-05-a": [],
        "geo-watch-Leonardo-2024-10-06-a": [],
        "geo-watch-2024-10-27-16-17-36-12059": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
